@@ -2,7 +2,6 @@ from .cli_loop import loop
 from .change_model import change_model
 from .search_command import search
 from .list_command import ListCommand
-from .config_command import ConfigCommands
 from .execute_command import ExecuteCommand
 from .assets_command import AssetsCommands
 from .onboarding import onboarding_command
@@ -15,7 +14,6 @@ __all__ = [
     "search",
     "change_model",
     "ListCommand",
-    "ConfigCommands",
     "ExecuteCommand",
     "AssetsCommands",
     "onboarding_command",
