@@ -1,5 +1,6 @@
 from pieces.urls import URLs
 from pieces.settings import Settings
+from pieces.copilot.ltm import enable_ltm
 
 def open_command(**kwargs):
     from pieces._vendor.pieces_os_client.models.inactive_os_server_applet import InactiveOSServerApplet
@@ -7,17 +8,22 @@ def open_command(**kwargs):
     copilot = kwargs.get("copilot", False)
     drive = kwargs.get("drive", False,)
     settings = kwargs.get("settings", False)
+    ltm = kwargs.get("ltm", False)
 
     # Let's try to Open POS
     health = Settings.pieces_client.open_pieces_os()
 
-    if (drive or copilot or settings) and not health:
+    if (drive or copilot or settings or ltm) and not health:
         Settings.logger.print("PiecesOS is not running")
         return
 
+    if ltm and enable_ltm(auto_enable=True):
+        Settings.logger.print("[green]LTM is enabled and running[/green]")
+
+
     if copilot:
         URLs.open_website(
-            "localhost:"
+            "http://localhost:"
             + str(
                 Settings.pieces_client.os_api.os_applet_launch(
                     InactiveOSServerApplet(type=OSAppletEnum.COPILOT)
@@ -26,7 +32,7 @@ def open_command(**kwargs):
         )
     if drive:
         URLs.open_website(
-            "localhost:"
+            "http://localhost:"
             + str(
                 Settings.pieces_client.os_api.os_applet_launch(
                     InactiveOSServerApplet(type=OSAppletEnum.SAVED_MATERIALS)
@@ -35,7 +41,7 @@ def open_command(**kwargs):
         )
     if settings:
         URLs.open_website(
-            "localhost:"
+            "http://localhost:"
             + str(
                 Settings.pieces_client.os_api.os_applet_launch(
                     InactiveOSServerApplet(
